@@ -3,9 +3,8 @@ import glob
 import logging
 import os
 from datetime import datetime
-from pathlib import Path
 from logging.config import fileConfig
-from dotenv import find_dotenv, load_dotenv
+from pathlib import Path
 
 import click
 import pandas as pd
@@ -13,16 +12,17 @@ import torch
 import torch.nn as nn
 import torch.nn.functional as f
 import torch.optim as optim
+from dotenv import find_dotenv, load_dotenv
 from numpy import mean
 from sklearn.model_selection import KFold
 from torch.utils.data import DataLoader
-from transformers import AutoModelForMaskedLM, CamembertForMaskedLM
+from transformers import AutoModelForMaskedLM
 import wandb
 
 from src.data.camembert_mlm_dataset import CamemBERTMaskedLMDataset
 from src.models.utils import count_parameters, init_tokenizer
 
-fileConfig('src/log_config.ini')
+fileConfig('log_config.ini')
 logger = logging.getLogger(__name__)
 
 
